import { Cache } from "../cache";
import { CommandInstance } from "../command";
import { Dispatcher } from "../dispatcher";
import { ClientResponseType, ClientType, ClientQueryParamsType } from "../client";
import { Builder } from "./";
import { AppManager } from "../managers";
import { NegativeTypes } from "../types";
/**
 * Configuration setup for the builder
 */
export declare type BuilderConfig = {
    /**
     * Url to your server
     */
    baseUrl: string;
    /**
     * Disable the web event listeners and actions on window object
     */
    isNodeJS?: boolean;
    /**
     * Custom client initialization prop
     */
    client?: ClientType;
    /**
     * Custom cache initialization prop
     */
    cache?: <B extends BuilderInstance, C extends Cache>(builder: B) => C;
    /**
     * Custom app manager initialization prop
     */
    appManager?: <B extends BuilderInstance, A extends AppManager>(builder: B) => A;
    /**
     * Custom fetch dispatcher initialization prop
     */
    fetchDispatcher?: <B extends BuilderInstance, D extends Dispatcher>(builder: B) => D;
    /**
     * Custom submit dispatcher initialization prop
     */
    submitDispatcher?: <B extends BuilderInstance, D extends Dispatcher>(builder: B) => D;
};
export declare type BuilderInstance = Builder<any, any>;
export declare type BuilderErrorType = Record<string, any> | string;
export declare type RequestInterceptorCallback = (command: CommandInstance) => Promise<CommandInstance> | CommandInstance;
export declare type ResponseInterceptorCallback<Response = any, Error = any> = (response: ClientResponseType<Response, Error>, command: CommandInstance) => Promise<ClientResponseType<any, any>> | ClientResponseType<any, any>;
export declare type StringifyCallbackType = (queryParams: ClientQueryParamsType | string | NegativeTypes) => string;
